@@ -6,7 +6,7 @@ Created on Tue Jul 12 13:34:22 2022
 @author: zengke
 """
 
-from BDMLtools.selector import binSelector,faSelector,preSelector,prefitModel,lassoSelector,binAdjuster
+from BDMLtools.selector import binSelector,faSelector,preSelector,prefitModel,LassoLogit,binAdjuster
 from BDMLtools.selector import stepLogit,cardScorer,LgbmSeqSelector,LgbmShapRFECVSelector,LgbmPISelector
 from BDMLtools.encoder import woeTransformer,binTransformer
 from sklearn.linear_model import LogisticRegression
@@ -22,7 +22,7 @@ def test_binSelector():
         {
          'a':np.arange(100,dtype='float'),
          'b':np.concatenate([[-999],np.ones(98),[999]]),
-         'c':np.concatenate([np.repeat('a',50),np.repeat('b',50)],dtype=object)}
+         'c':np.concatenate([np.repeat('a',30),np.repeat('b',30),np.repeat('c',30),np.repeat('d',10)],dtype=object)}
         )
     
     ws=pd.Series(np.ones(100),name='ws')
@@ -34,7 +34,7 @@ def test_binSelector():
     binSelector(method='freq',sample_weight=ws,keep=['a','c']).fit_transform(X,y)   
     binSelector(method='freq',special_values=[1,2,3,4,'a']).fit_transform(X,y)        
     
-    binSelector(method='freq-kmeans',n_jobs=1,iv_limit=0).fit_transform(X,y)        
+    binSelector(method='freq-kmeans',n_jobs=1,iv_limit=0,bin_num_limit=2).fit_transform(X,y)       
     binSelector(method='freq-kmeans',n_jobs=1,iv_limit=0,coerce_monotonic=True).fit_transform(X,y)   
     binSelector(method='freq-kmeans',n_jobs=1,iv_limit=0,sample_weight=ws,keep=['a','c']).fit_transform(X,y)   
     binSelector(method='freq-kmeans',n_jobs=1,iv_limit=0,special_values=[1,2,3,4,'a']).fit_transform(X,y)        
@@ -206,14 +206,57 @@ def test_preSelector():
     assert 'a' in res.columns
     res=preSelector(out_path='tmp').fit_transform(X,y) 
 
-def test_lassoSelector():
+def test_lassologit():
+    
+    from sklearn.datasets import load_breast_cancer
+    import matplotlib
     
     X=pd.DataFrame(
-        {'a':[1,2,2,4,5],'b':[1,2,3,4,5],'c':[1,1,1,2,1]}
-        )
-    y=pd.Series([0,0,1,1,1],name='y')
+        load_breast_cancer()['data'],columns=['v'+str(i) for i in range(30)]
+        )[['v22','v24','v21','v28','v15','v6','v11','v13','v27','v14']]
+    y=pd.Series(load_breast_cancer()['target'],name='y')
+    ws=pd.Series(np.ones(y.size),index=y.index)
     
-    lassoSelector().fit_transform(X,y)
+    X=X[['v22','v24','v21','v28']]
+    
+    res=LassoLogit(c_num=10,standard=True,metric='roc_auc',n_jobs=1).fit_plot(X,y)
+    
+    assert isinstance(res.plot_path,matplotlib.figure.Figure)
+    assert isinstance(res.plot_valscore,matplotlib.figure.Figure)
+    assert hasattr(res,'cv_path_')
+    assert hasattr(res,'cv_res_')
+    assert hasattr(res,'feature_names_')
+    assert hasattr(res,'model_refit')
+    
+    res.predict_proba(X)
+    res.transform(X)
+    
+    res=LassoLogit(c_num=10,standard=True,metric='neglogloss',n_jobs=1).fit_plot(X,y)
+    
+    assert isinstance(res.plot_path,matplotlib.figure.Figure)
+    assert isinstance(res.plot_valscore,matplotlib.figure.Figure)
+    assert hasattr(res,'cv_path_')
+    assert hasattr(res,'cv_res_')
+    assert hasattr(res,'feature_names_')
+    assert hasattr(res,'model_refit')
+    
+    res.predict_proba(X)
+    res.transform(X)    
+    
+    res.refit_with_C(X, y, C=1)
+    assert res.model_refit.C==1
+    
+    res=LassoLogit(c_num=10,standard=True,metric='neglogloss',n_jobs=1).fit_plot(X,y,ws)
+    
+    assert isinstance(res.plot_path,matplotlib.figure.Figure)
+    assert isinstance(res.plot_valscore,matplotlib.figure.Figure)
+    assert hasattr(res,'cv_path_')
+    assert hasattr(res,'cv_res_')
+    assert hasattr(res,'feature_names_')
+    assert hasattr(res,'model_refit')    
+    
+    res.predict_proba(X)
+    res.transform(X) 
     
 
 def test_LgbmSeqSelector():
@@ -346,7 +389,7 @@ def test_woeTransformer():
         
         assert X_woe[col].round(4).equals(X_woe1[col].round(4))
         
-    X_woe=woeTransformer(bins,woe_missing=0,distr_limit=0.05).fit_transform(X,y)  
+    X_woe=woeTransformer(bins,woe_missing=0,distr_limit=0.05,woe_special=0).fit_transform(X,y)  
     assert all(X_woe['var_32'][X['var_32'].isnull()]==0)
     
     X=pd.DataFrame({'var_num':[0,1,1,3,np.nan,4,5,1,0,1],
